from flask import redirect, url_for, request, flash
from flask_login import login_required, current_user, logout_user
from app import app, db
from app.forms.account import UpdateAccountForm, RegistrationForm, DeleteAccountForm
from app.models.users import Member
from app.utils.render import render

@app.route('/account', methods=['GET', 'POST'])
@login_required
def account():
    form = UpdateAccountForm()
    del_form = DeleteAccountForm()
    if request.method == "POST":
        if form.validate_on_submit():
            # Updates to do
            updates = {}
            # Optional updates (do not update if blank)
            if form.email.data:
                updates['email'] = form.email.data
            if form.password.data:
                updates['password'] = form.password.data
            # Required updates (update if blank)
            updates.update({
                "signature":  form.signature.data,
                "bio":        form.biography.data,
                "birthday":   form.birthday.data,
                "newsletter": form.newsletter.data
            })
            # Do the fucking updates
            current_user.update(**updates)
            db.session.merge(current_user)
            db.session.commit()
            flash('Modifications effectuées', 'ok')
        else:
            flash('Erreur lors de la modification', 'error')

    return render('account.html', form=form, del_form=del_form)

@app.route('/account/delete', methods=['GET', 'POST'])
def delete_account():
    del_form = DeleteAccountForm()
    if del_form.validate_on_submit():
        db.session.delete(current_user)
        logout_user()
        db.session.commit()
        flash('Compte supprimé', 'ok')
        return redirect(url_for('index'))
    else:
        flash('Erreur lors de la suppression du compte', 'error')
        return render('delete_account.html', del_form=del_form)

@app.route('/register', methods=['GET', 'POST'])
def register():
    if current_user.is_authenticated:
        return redirect(url_for('index'))
    form = RegistrationForm()
    if form.validate_on_submit():
        member = Member(form.username.data, form.email.data, form.password.data)
        db.session.add(member)
        db.session.commit()
        flash('Inscription réussie', 'ok')
        return redirect(url_for('validation'))
    return render('register.html', title='Register', form=form)

@app.route('/register/validation/')
def validation():
    if current_user.is_authenticated :
        return redirect(url_for('index'))
    return render('validation.html')
